@@ -1,4 +1,4 @@
-#' @title Statistics on Species or Infraspecies by Province
+#' @title Statistics on Species or Infraspecies by Province from Catalogue of Life China checklist
 #' @description Download the statistics datasets on species/infraspecies by province at \url{http://sp2000.org.cn/statistics/statistics_map} for more details.
 #' @rdname  get_province
 #' @name get_province
@@ -15,7 +15,8 @@
 get_province <- function() {
   url <- 'http://sp2000.org.cn/statistics/show_in_map_all'
   map_all <- fromJSON(url)
-  names(map_all$data) <- c("province", "species_counts")
+  map_all <- map_all$data
+  names(map_all) <- c("province","species_counts")
   map_all$date <- as.Date(Sys.time())
   return(map_all)
 }
